@@ -51,9 +51,6 @@
 #include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4ui/libxfce4ui.h>
 
-#define EXO_API_SUBJECT_TO_CHANGE
-#include <exo/exo.h>
-
 #include <string.h>
 
 #include "view.h"
@@ -216,7 +213,9 @@ pview_bookmark_action_call_wrapper(PlacesView *view, PlacesBookmarkAction *actio
 
 /* Menu callbacks */
 static gboolean /* return false to stop calling it */
-pview_cb_menu_timeout(PlacesView *pd){
+pview_cb_menu_timeout(gpointer user_data)
+{
+    PlacesView *pd = user_data;
 
     if(!pd->menu_timeout_id)
         goto killtimeout;
@@ -447,8 +446,7 @@ pview_cb_recent_items_clear(GtkWidget *clear_item, GtkWidget *recent_menu)
 {
     GtkRecentManager *manager = gtk_recent_manager_get_default();
 
-    gint removed = gtk_recent_manager_purge_items(manager, NULL);
-    DBG("Cleared %d recent items", removed);
+    DBG("Cleared %d recent items", gtk_recent_manager_purge_items(manager, NULL));
 
     pview_cb_recent_changed(manager, recent_menu);
 
@@ -611,8 +609,7 @@ pview_update_menu(PlacesView *pd)
     pd->menu = gtk_menu_new();
 
     /* make sure the menu popups up in right screen */
-    /* need exo_noop for GTK 2.6 and 2.8; starting with 2.10, NULL is OK */
-    gtk_menu_attach_to_widget(GTK_MENU(pd->menu), pd->button, (GtkMenuDetachFunc) exo_noop);
+    gtk_menu_attach_to_widget(GTK_MENU(pd->menu), pd->button, NULL);
     gtk_menu_set_screen(GTK_MENU(pd->menu),
                         gtk_widget_get_screen(pd->button));
 
@@ -760,7 +757,7 @@ pview_open_menu_at (PlacesView   *pd,
     /* menu timeout to poll for model changes */
     if(pd->menu_timeout_id == 0){
         pd->menu_timeout_id = g_timeout_add_seconds_full(G_PRIORITY_LOW, 2,
-                                   (GSourceFunc) pview_cb_menu_timeout, pd,
+                                   pview_cb_menu_timeout, pd,
                                    NULL);
         PLACES_DEBUG_MENU_TIMEOUT_COUNT(1);
     }else{
